@@ -11,10 +11,10 @@
 .onAttach <- function(libname, pkgname){
   
   ## show startup message
-  try(packageStartupMessage("Welcome to another bright 'eseis' session."), 
-      silent = TRUE)
+  # try(packageStartupMessage("Welcome to another bright 'eseis' session."), 
+  #     silent = TRUE)
   
   ## try to load obspy library
-  obspy <- try(reticulate::import("obspy"),
-               silent = TRUE)
+  # obspy <- try(reticulate::import("obspy"),
+  #              silent = TRUE)
 }
